🔉 vl8: Create derivative works that might not be copyright violations 🔉
----------------------------------------------------------------------------

This is a tool to create derivative works of pieces of music.
